@@ -3,8 +3,6 @@
 
 #include <stdio.h>
 
-void		*abook_malloc(size_t size);
-void		*abook_realloc(void *ptr, size_t size);
 FILE		*abook_fopen (const char *path, const char *mode);
 void		quit_abook(int save_db);
 void		launch_wwwbrowser(int item);
@@ -19,8 +17,8 @@ int		strncasecmp (const char *, const char *, size_t);
 
 #define Y_STATUSLINE   	(LINES - 2)
 
-#define MIN_LINES	20	
-#define MIN_COLS	70	
+#define MIN_LINES	20
+#define MIN_COLS	70
 
 #define DEFAULT_UMASK	066
 #define DIR_IN_HOME	".abook"
@@ -39,9 +37,7 @@ int		strncasecmp (const char *, const char *, size_t);
 #define show_cursor()	curs_set(1)
 
 #define safe_atoi(X)    ((X == NULL) ? 0 : atoi(X))
-#define my_free(X)	do {free(X); X=NULL;} while(0)
 #define safe_str(X)	((X == NULL) ? "" : X)
-#define safe_strdup(X)	((X == NULL) ? NULL : strdup(X))
 
 #ifndef min
 #       define min(x,y) (((x)<(y)) ? (x):(y))
