@@ -1,6 +1,6 @@
 
 /*
- * $Id: edit.c,v 1.32 2004/04/03 16:05:41 jheinonen Exp $
+ * $Id: edit.c,v 1.38 2005/08/13 10:49:25 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -17,6 +17,7 @@
 #include "list.h"
 #include "edit.h"
 #include "misc.h"
+#include "xmalloc.h"
 #ifdef HAVE_CONFIG_H
 #	include "config.h"
 #endif
@@ -46,13 +47,13 @@ editor_tab(const int tab)
 		"CUSTOM "
 	};
 
-	mvwhline(editw, TABLINE+1, 0, UI_HLINE_CHAR, EDITW_COLS);
-	for(i=0; i < TABS; i++) {
+	mvwhline(editw, TABLINE + 1, 0, UI_HLINE_CHAR, EDITW_COLS);
+	for(i = 0; i < TABS; i++) {
 		mvwaddch(editw,  TABLINE+1, spacing * i + 2,  UI_TEE_CHAR);
 		mvwaddch(editw,  TABLINE+1, spacing * i + 12, UI_TEE_CHAR);
 	}
 
-	for(i=0; i < TABS; i++) {
+	for(i = 0; i < TABS; i++) {
 		mvwaddch(editw,  TABLINE, spacing * i + 2,  UI_ULCORNER_CHAR);
 		mvwaddch(editw,  TABLINE, spacing * i + 3,  UI_LBOXLINE_CHAR);
 		mvwaddstr(editw, TABLINE, spacing * i + 4,  tab_names[i]);
@@ -97,7 +98,7 @@ roll_emails(int item)
 
 	strcpy(database[item][EMAIL], p+1);
 	strcat(database[item][EMAIL], ",");
-	strcat(database[item][EMAIL], tmp);	
+	strcat(database[item][EMAIL], tmp);
 }
 
 static void
@@ -109,17 +110,50 @@ init_editor()
 	refresh_statusline();
 }
 
-/*
- * we have to introduce edit_undo here
- */
-static void edit_undo(int item, int mode);
-
 enum {
 	BACKUP_ITEM,
 	RESTORE_ITEM,
 	CLEAR_UNDO
 };
 
+static void
+edit_undo(int item, int mode)
+{
+	int i;
+	static list_item *backup = NULL;
+
+	switch(mode) {
+		case CLEAR_UNDO:
+			if(backup) {
+				free_list_item(backup[0]);
+				xfree(backup);
+			}
+			break;
+		case BACKUP_ITEM:
+			if(backup) {
+				free_list_item(backup[0]);
+				xfree(backup);
+			}
+			backup = xmalloc(sizeof(list_item));
+			for(i = 0; i < ITEM_FIELDS; i++)
+				if(database[item][i] == NULL)
+					backup[0][i] = NULL;
+				else
+					backup[0][i] =
+						xstrdup(database[item][i]);
+			break;
+		case RESTORE_ITEM:
+			if(backup) {
+				free_list_item(database[item]);
+				itemcpy(database[item], backup[0]);
+				xfree(backup);
+			}
+			break;
+		default:
+			assert(0);
+	}
+}
+
 
 static void
 close_editor()
@@ -135,12 +169,12 @@ print_editor_header(int item)
 	char *header;
 	char email[MAX_EMAIL_LEN];
 
-	if( (header = (char *)malloc(EDITW_COLS)) == NULL )
+	if((header = xmalloc(EDITW_COLS)) == NULL)
 		return;
 
 	get_first_email(email, item);
 
-	if( *database[item][EMAIL] )
+	if(*database[item][EMAIL])
 		snprintf(header, EDITW_COLS, "%s <%s>",
 				database[item][NAME],
 				email);
@@ -163,7 +197,7 @@ editor_print_data(int tab, int item)
 		if(abook_fields[i].tab != tab)
 			continue;
 
-		if(i==EMAIL) { /* special field */
+		if(i == EMAIL) { /* special field */
 			int k;
 			char emails[MAX_EMAILS][MAX_EMAIL_LEN];
 			split_emailstr(item, emails);
@@ -181,7 +215,8 @@ editor_print_data(int tab, int item)
 		}
 
 		if(j > 1) {
-			getyx(editw, y, x); y++;
+			getyx(editw, y, x);
+			y++;
 		} else
 			y = FIELDS_START_Y;
 
@@ -218,7 +253,7 @@ change_field(char *msg, char **field)
 	char *old;
 	int ret = 0;
 
-	if( !strncmp("E-mail", msg, 6) )
+	if(!strncmp("E-mail", msg, 6))
 		max_len = MAX_EMAIL_LEN;
 
 	old = *field;
@@ -226,9 +261,9 @@ change_field(char *msg, char **field)
 	*field = ui_readline(msg, old, max_len - 1, 0);
 
 	if(*field) {
-		free(old);
+		xfree(old);
 		if(!**field)
-			my_free(*field);
+			xfree(*field);
 	} else {
 		*field = old;
 		ret = 1;
@@ -245,21 +280,21 @@ change_name_field(char **field)
 {
 	char *tmp;
 
-	tmp = strdup(*field);
+	tmp = xstrdup(*field);
 	change_field("Name: ", field);
 
-	if( *field == NULL || ! **field ) {
-		my_free(*field);
-		*field = strdup(tmp);
+	if(*field == NULL || ! **field) {
+		xfree(*field);
+		*field = xstrdup(tmp);
 	}
 
-	my_free(tmp);
+	xfree(tmp);
 }
 
 static void
 fix_email_str(char *str)
 {
-	for(; *str; str++ )
+	for(; *str; str++)
 		*str = *str == ',' ? '_' : *str;
 }
 
@@ -273,7 +308,7 @@ edit_emails(char c, int item)
 	int email_num = c - '2';
 
 	split_emailstr(item, emails);
-	field = strdup(emails[email_num]);
+	field = xstrdup(emails[email_num]);
 
 	if(change_field("E-mail: ", &field))
 		return; /* user cancelled ( C-g ) */
@@ -284,7 +319,7 @@ edit_emails(char c, int item)
 	} else
 		*emails[email_num] = 0;
 
-	my_free(database[item][EMAIL]);
+	xfree(database[item][EMAIL]);
 
 	for(i = 0; i < MAX_EMAILS; i++) {
 		if( *emails[i] ) {
@@ -297,7 +332,7 @@ edit_emails(char c, int item)
 	if(tmp[len -1] == ',')
 		tmp[len-1] =0;
 
-	database[item][EMAIL] = strdup(tmp);
+	database[item][EMAIL] = xstrdup(tmp);
 }
 
 static int
@@ -325,14 +360,14 @@ edit_field(int tab, char c, int item)
 		return 1;
 	}
 
-	for(i=0, j=0; i< ITEM_FIELDS; i++) {
+	for(i = 0, j = 0; i< ITEM_FIELDS; i++) {
 		if(abook_fields[i].tab == tab)
 			j++;
 		if(j==n)
 			break;
 	}
 
-	if(j!=n)
+	if(j != n)
 		return 0;
 
 	str = mkstr("%s: ", abook_fields[i].name);
@@ -343,40 +378,6 @@ edit_field(int tab, char c, int item)
 	return 1;
 }
 
-static void
-edit_undo(int item, int mode)
-{
-	int i;
-	static list_item *backup = NULL;
-
-	switch(mode) {
-		case CLEAR_UNDO:
-			if(backup) {
-				free_list_item(backup[0]);
-				my_free(backup);
-			}
-			break;
-		case BACKUP_ITEM:
-			if(backup) {
-				free_list_item(backup[0]);
-				my_free(backup);
-			}
-			backup = (list_item *)abook_malloc(sizeof(list_item));
-			for(i = 0; i < ITEM_FIELDS; i++)
-				backup[0][i] = safe_strdup(database[item][i]);
-			break;
-		case RESTORE_ITEM:
-			if(backup) {
-				free_list_item(database[item]);
-				itemcpy(database[item], backup[0]);
-				my_free(backup);
-			}
-			break;
-		default:
-			assert(0);
-	}
-}
-
 static int
 edit_loop(int item)
 {
@@ -394,7 +395,7 @@ edit_loop(int item)
 	refresh();
 	wrefresh(editw);
 
-	switch( (c = getch()) ) {
+	switch((c = getch())) {
 		case 'c': tab = TAB_CONTACT; break;
 		case 'a': tab = TAB_ADDRESS; break;
 		case 'p': tab = TAB_PHONE; break;
@@ -411,7 +412,7 @@ edit_loop(int item)
 		case 'k': if(is_valid_item(item-1)) item--; break;
 		case KEY_DOWN:
 		case '>':
-		case 'j': if(is_valid_item(item+1)) item++; break;
+		case 'j': if(is_valid_item(item + 1)) item++; break;
 		case 'r': roll_emails(item); break;
 		case '?': display_help(HELP_EDITOR); break;
 		case 'u': edit_undo(item, RESTORE_ITEM); break;
@@ -436,7 +437,7 @@ edit_item(int item)
 
 	init_editor();
 
-	while( (item = edit_loop(item)) >= 0 )
+	while((item = edit_loop(item)) >= 0)
 		curitem = item; /* hmm, this is not very clean way to go */
 
 	close_editor();
